==> cheddar-osate2_1.0.0.201901031910.jar: src/cheddar/aadl/To_Dependency.java <==
package cheddar.aadl;

import java.util.HashMap;

import org.osate.aadl2.instance.ComponentInstance;
import org.osate.aadl2.instance.ConnectionInstance;
import org.osate.aadl2.instance.ConnectionInstanceEnd;
import org.osate.aadl2.instance.ConnectionKind;
import org.osate.aadl2.instance.FeatureInstance;

import cheddar.adl.Critical_Section;
import cheddar.adl.Dependency_Union;
import cheddar.adl.Generic_Resource;
import cheddar.adl.Generic_Task;
import cheddar.adl.Periodic_Task;
import cheddar.adl.Precedence_Dependency_Type;
import cheddar.adl.Resource_Dependency_Type;
import cheddar.adl.Tasks_Type;
import cheddar.adl.Time_Triggered_Communication_Dependency_Type;
import cheddar.adl.Time_Triggered_Communication_Timing_Property_Type;
import cheddar.osate2_plugin.Config;
import cheddar.osate2_plugin.Debug;

public class To_Dependency {

	static public void Shared_Resource_Dependency(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component, ConnectionInstance connection) {

		// Add resource dependencies related to the resource
		//
		ConnectionInstanceEnd source = connection.getSource();

		Generic_Task gt = result.Search_Task(component.getFullName().toString());
		Generic_Resource re = result.Search_Resource(source.getName());

		if ((gt != null) && (re != null)) {
			Debug.Put("add resource dependency " + re.getName() + " " + gt.getName());

			Critical_Section cs = new Critical_Section();
			cs.setTaskBegin(1);
			cs.setTaskEnd(gt.getCapacity());
			HashMap<String, Critical_Section> css = re.getCriticalSections();
			if (css == null) {
				css = new HashMap<String, Critical_Section>();
				re.setCriticalSections(css);
			}
			css.put(gt.getName(), cs);

			Resource_Dependency_Type res_dep = new Resource_Dependency_Type();
			res_dep.setcheddarXmlId(id.getAndIncrement());
			res_dep.setResourceDependencyResource(re);
			res_dep.setResourceDependencyTask(gt);

			Dependency_Union dep = new Dependency_Union();
			dep.setResourceDependency(res_dep);

			result.dependencies.add(dep);
		}
	}


	static public void Data_Port_Dependency(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component, ConnectionInstance connection) {

		ConnectionInstanceEnd source = connection.getSource();
		ConnectionInstanceEnd destination = connection.getDestination();

		Generic_Task destination_gt = result.Search_Task(destination.getComponentInstance().getName());
		Generic_Task source_gt = result.Search_Task(source.getComponentInstance().getName());
		Time_Triggered_Communication_Timing_Property_Type protocol = Properties_With_Default_Value
				.getConnectionTiming(connection);

		// Map data port to Cheddar precedency with the following rules:
		// Sampled protocol : nothing to do
		// Delayed protocol : add offset to sink task
		// Immediate protocol : add precedency entities
		//
		if ((source_gt != null) && (destination_gt != null)) {

			// Map to Precedencies
			//
			if (Config.Data_Port_To_Precedencies) {

				if (protocol == Time_Triggered_Communication_Timing_Property_Type.Sampled_Timing) {
					return;
				} else if (protocol == Time_Triggered_Communication_Timing_Property_Type.Delayed_Timing) {
					if ( (source_gt.getTaskType() == Tasks_Type.Periodic_Type)
							|| (source_gt.getTaskType() == Tasks_Type.Poisson_Type)
						    || (source_gt.getTaskType() == Tasks_Type.Sporadic_Type) )
						{
						Periodic_Task pt = (Periodic_Task)source_gt;
						destination_gt.setStartTime(pt.getPeriod());
					}
				}
				else
				{
					Debug.Put("add task precedency for Immediate data port connection " + source_gt.getName() + " "
							+ destination_gt.getName());

					Precedence_Dependency_Type prec_dep = new Precedence_Dependency_Type();
					prec_dep.setcheddarXmlId(id.getAndIncrement());
					prec_dep.setPrecedenceSink(destination_gt);
					prec_dep.setPrecedenceSource(source_gt);

					Dependency_Union dep = new Dependency_Union();
					dep.setcheddarXmlId(id.getAndIncrement());
					dep.setPrecedenceDependency(prec_dep);

					result.dependencies.add(dep);
					}
		}

		// Map data port to Cheddar time trigerred entities
		else {

			Debug.Put("add Time triggered dependency  " + source_gt.getName() + " " + destination_gt.getName());

			Time_Triggered_Communication_Dependency_Type ttc_dep = new Time_Triggered_Communication_Dependency_Type();
			ttc_dep.setcheddarXmlId(id.getAndIncrement());
			ttc_dep.setTimeTriggeredCommunicationSink(destination_gt);
			ttc_dep.setTimeTriggeredCommunicationSource(source_gt);
			Dependency_Union dep = new Dependency_Union();
			dep.setTimeTriggeredCommunicationDependency(ttc_dep);

			result.dependencies.add(dep);
		}
		}
	}


	static public void Thread_Component_Dependencies(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component) {

		// Look for feature connections
		//
		for (FeatureInstance featureInstance : component.getFeatureInstances()) {
			for (ConnectionInstance connection : featureInstance.getDstConnectionInstances()) {
				if (connection.getKind() == ConnectionKind.ACCESS_CONNECTION) {
					To_Dependency.Shared_Resource_Dependency(result, id, component, connection);
				}
				if (connection.getKind() == ConnectionKind.PORT_CONNECTION) {
					To_Dependency.Data_Port_Dependency(result, id, component, connection);
				}
			}
		}
	}

}

==> cheddar-osate2_1.0.0.201901081024.jar: src/cheddar/aadl/To_Dependency.java <==
package cheddar.aadl;

import java.util.HashMap;

import org.osate.aadl2.instance.ComponentInstance;
import org.osate.aadl2.instance.ConnectionInstance;
import org.osate.aadl2.instance.ConnectionInstanceEnd;
import org.osate.aadl2.instance.ConnectionKind;
import org.osate.aadl2.instance.FeatureInstance;

import cheddar.adl.Critical_Section;
import cheddar.adl.Dependency;
import cheddar.adl.Dependency_Type;
import cheddar.adl.Dependency_Union;
import cheddar.adl.Generic_Resource;
import cheddar.adl.Generic_Task;
import cheddar.adl.Periodic_Task;
import cheddar.adl.Precedence_Dependency_Type;
import cheddar.adl.Resource_Dependency_Type;
import cheddar.adl.Tasks_Type;
import cheddar.adl.Time_Triggered_Communication_Dependency_Type;
import cheddar.adl.Time_Triggered_Communication_Timing_Property_Type;
import cheddar.osate2_plugin.Config;
import cheddar.osate2_plugin.Debug;

public class To_Dependency {

	static public void Shared_Resource_Dependency(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component, ConnectionInstance connection) {

		// Add resource dependencies related to the resource
		//
		ConnectionInstanceEnd source = connection.getSource();

		Generic_Task gt = result.Search_Task(component.getFullName().toString());
		Generic_Resource re = result.Search_Resource(source.getName());

		if ((gt != null) && (re != null)) {
			Debug.Put("add resource dependency " + re.getName() + " " + gt.getName());

			Critical_Section cs = new Critical_Section();
			cs.setTaskBegin(1);
			cs.setTaskEnd(gt.getCapacity());
			HashMap<String, Critical_Section> css = re.getCriticalSections();
			if (css == null) {
				css = new HashMap<String, Critical_Section>();
				re.setCriticalSections(css);
			}
			css.put(gt.getName(), cs);

			Resource_Dependency_Type res_dep = new Resource_Dependency_Type();
			res_dep.setcheddarXmlId(id.getAndIncrement());
			res_dep.setResourceDependencyResource(re);
			res_dep.setResourceDependencyTask(gt);

			Dependency_Union dep = new Dependency_Union();
			dep.setResourceDependency(res_dep);

			Dependency root = new Dependency();
			root.setTypeOfDependency(Dependency_Type.Resource_Dependency);
			root.setUnion(dep);

			result.dependencies.add(root);
		}
	}


	static public void Data_Port_Dependency(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component, ConnectionInstance connection) {

		ConnectionInstanceEnd source = connection.getSource();
		ConnectionInstanceEnd destination = connection.getDestination();

		Generic_Task destination_gt = result.Search_Task(destination.getComponentInstance().getName());
		Generic_Task source_gt = result.Search_Task(source.getComponentInstance().getName());
		Time_Triggered_Communication_Timing_Property_Type protocol = Properties_With_Default_Value
				.getConnectionTiming(connection);

		// Map data port to Cheddar precedency with the following rules:
		// Sampled protocol : nothing to do
		// Delayed protocol : add offset to sink task
		// Immediate protocol : add precedency entities
		//
		if ((source_gt != null) && (destination_gt != null)) {

			// Map to Precedencies
			//
			if (Config.Data_Port_To_Precedencies) {

				if (protocol == Time_Triggered_Communication_Timing_Property_Type.Sampled_Timing) {
					return;
				} else if (protocol == Time_Triggered_Communication_Timing_Property_Type.Delayed_Timing) {
					if ( (source_gt.getTaskType() == Tasks_Type.Periodic_Type)
							|| (source_gt.getTaskType() == Tasks_Type.Poisson_Type)
						    || (source_gt.getTaskType() == Tasks_Type.Sporadic_Type) )
						{
						Periodic_Task pt = (Periodic_Task)source_gt;
						destination_gt.setStartTime(pt.getPeriod());
					}
				}
				else
				{
					Debug.Put("add task precedency for Immediate data port connection " + source_gt.getName() + " "
							+ destination_gt.getName());

					Precedence_Dependency_Type prec_dep = new Precedence_Dependency_Type();
					prec_dep.setcheddarXmlId(id.getAndIncrement());
					prec_dep.setPrecedenceSink(destination_gt);
					prec_dep.setPrecedenceSource(source_gt);

					Dependency_Union dep = new Dependency_Union();
					dep.setcheddarXmlId(id.getAndIncrement());
					dep.setPrecedenceDependency(prec_dep);

					Dependency root = new Dependency();
					root.setTypeOfDependency(Dependency_Type.Precedence_Dependency);
					root.setUnion(dep);

					result.dependencies.add(root);
					}
		}

			/*
			 * NOUVELLE VERSION
			 * Resource_Dependency_Type res_dep = new Resource_Dependency_Type();
			 * res_dep.setcheddarXmlId(id.getAndIncrement());
			 * res_dep.setResourceDependencyResource(re);
			 * res_dep.setResourceDependencyTask(gt);
			 *
			 * Dependency_Union dep = new Dependency_Union();
			 * dep.setResourceDependency(res_dep);
			 *
			 * Dependency root = new Dependency();
			 * root.setTypeOfDependency(Dependency_Type.Resource_Dependency);
			 * root.setUnion(dep);
			 *
			 * result.dependencies.add(root);
			 */

		// Map data port to Cheddar time trigerred entities
		else {

			Debug.Put("add Time triggered dependency  " + source_gt.getName() + " " + destination_gt.getName());

			Time_Triggered_Communication_Dependency_Type ttc_dep = new Time_Triggered_Communication_Dependency_Type();
			ttc_dep.setcheddarXmlId(id.getAndIncrement());
			ttc_dep.setTimeTriggeredCommunicationSink(destination_gt);
			ttc_dep.setTimeTriggeredCommunicationSource(source_gt);
			Dependency_Union dep = new Dependency_Union();
			dep.setTimeTriggeredCommunicationDependency(ttc_dep);
				Dependency root = new Dependency();
				root.setTypeOfDependency(Dependency_Type.Time_Triggered_Communication_Dependency);
				root.setUnion(dep);

				result.dependencies.add(root);

			}
		}
	}


	static public void Thread_Component_Dependencies(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component) {

		// Look for feature connections
		//
		for (FeatureInstance featureInstance : component.getFeatureInstances()) {
			for (ConnectionInstance connection : featureInstance.getDstConnectionInstances()) {
				if (connection.getKind() == ConnectionKind.ACCESS_CONNECTION) {
					To_Dependency.Shared_Resource_Dependency(result, id, component, connection);
				}
				if (connection.getKind() == ConnectionKind.PORT_CONNECTION) {
					To_Dependency.Data_Port_Dependency(result, id, component, connection);
				}
			}
		}
	}

}
